import os
import xml.etree.ElementTree as ET

import click
import requests
import sienna
from schnitsum import SchnitSum
from tqdm import tqdm

from acltldr.utils import papers_to_markdown_items


@click.command()
@click.argument("url", type=str)
@click.argument("odir", type=str, default="./")
@click.option("--prefix", type=str, default=None)
@click.option("--use-gpu", is_flag=True, show_default=True, default=False)
def run(url: str, odir: str, prefix: str, use_gpu: bool):
    assert url.endswith(".xml"), "Needs to be a xml file."
    prefix = "out" if prefix is None else prefix

    response = requests.get(url)
    tree = ET.ElementTree(ET.fromstring(response.content))
    root = tree.getroot()
    model = SchnitSum(model_name="sobamchan/bart-large-scitldr", use_gpu=use_gpu)

    papers = []
    for node in tqdm(root[0].findall("paper")):
        _title = (
            ET.tostring(node.find("title"), method="text", encoding="utf8")
            .strip()
            .decode("UTF-8")
        )
        _authors = []
        for _author_node in node.findall("author"):
            _authors.append(
                f"{_author_node.find('first').text} {_author_node.find('last').text}"
            )
        _abst = node.find("abstract").text
        _url = f"https://aclanthology.org/{node.find('url').text}"

        papers.append(
            {
                "title": _title,
                "authors": _authors,
                "abstract": _abst,
                "tldr": model([_abst])[0] if isinstance(_abst, str) else "",
                "url": _url,
            }
        )

    sienna.save(papers, os.path.join(odir, f"{prefix}.papers.jsonl"))

    md_items = papers_to_markdown_items(papers)
    with open(os.path.join(odir, f"{prefix}.papers.md"), "w") as f:
        f.write("\n".join(md_items))


if __name__ == "__main__":
    run()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['acltldr']

package_data = \
{'': ['*']}

install_requires = \
['click>=8.1.3,<9.0.0',
 'requests>=2.29.0,<3.0.0',
 'schnitsum>=0.4.6,<0.5.0',
 'sienna>=0.2.2,<0.3.0',
 'tqdm>=4.65.0,<5.0.0']

entry_points = \
{'console_scripts': ['acltldr = acltldr.main:run']}

setup_kwargs = {
    'name': 'acltldr',
    'version': '0.1.1',
    'description': '',
    'long_description': '# ACLTLDR\n\nThis is a python-based CLI tool used to generate summaries for ACL conference papers on [this page](https://sotaro.io/tldrs).\n\n\n## Installation\n\n```\npip install acltldr\n```\n\n\n## Usage\n\nAn example command to generate summaries for the proceedings of EACL 2021.\nFollowing command will generate a jsonl file with all the data, and a markdown file for the post.\n\n```\nacltldr https://raw.githubusercontent.com/acl-org/acl-anthology/master/data/xml/2021.eacl.xml \\\n        ./ \\\n\t--prefix "2021.eacl" \\\n\t--use-gpu\n```\n',
    'author': 'sobamchan',
    'author_email': 'oh.sore.sore.soutarou@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
